<?php
/**
 * Plugin Name: Export Featured Image Data for eZbloo
 * Plugin URI:  https://ezbloo.com
 * Description: Exports post metadata where meta_key is `_thumbnail_id` to a CSV file for eZbloo.
 * Version:     1.0
 * Author:      Maximus McCullough
 * Author URI:  https://a1websitepro.com
 * License:     GPL2
 */

if (!defined('ABSPATH')) {
    exit; // Prevent direct access
}

// Function to export featured images
function export_featured_images() {
    global $wpdb;

    // Query to get post IDs and their featured image IDs
    $results = $wpdb->get_results("
        SELECT p.ID AS post_id, p.post_title, pm.meta_value AS thumbnail_id, wp.guid AS image_url
        FROM {$wpdb->posts} p
        LEFT JOIN {$wpdb->postmeta} pm ON p.ID = pm.post_id
        LEFT JOIN {$wpdb->posts} wp ON pm.meta_value = wp.ID
        WHERE pm.meta_key = '_thumbnail_id'
        AND wp.post_type = 'attachment'
    ", ARRAY_A);

    if (!$results) {
        wp_die("No data found to export.");
    }

    // Set headers for CSV file download
    header('Content-Type: text/csv; charset=UTF-8');
    header('Content-Disposition: attachment; filename="featured_images_export.csv"');

    $output = fopen('php://output', 'w');
    fputcsv($output, ['Post ID', 'Post Title', 'Thumbnail ID', 'Image URL']); // Column headers

    foreach ($results as $row) {
        fputcsv($output, [$row['post_id'], $row['image_url']]);
    }

    fclose($output);
    exit;
}

// Add admin menu option
function export_featured_images_menu() {
    add_menu_page(
        'Export Featured Images',  // Page title
        'Export Images',           // Menu title
        'manage_options',          // Capability
        'export-featured-images',  // Menu slug
        'export_featured_images_page', // Function to display the page
        'dashicons-download',      // Icon
        20                         // Position
    );
}
add_action('admin_menu', 'export_featured_images_menu');

// Function to display the export page
function export_featured_images_page() {
    ?>
    <div class="wrap">
        <h2>Export Featured Images For eZbloo</h2>
        <p>Click the button below to download a CSV file of all posts with featured images. You will use this file to upload to eZbloo to set all your featured images.</p>
        <a href="<?php echo admin_url('admin-post.php?action=export_featured_images'); ?>" class="button button-primary">Download CSV</a>
    </div>
    <?php
}

// Hook for processing export action
add_action('admin_post_export_featured_images', 'export_featured_images');
